==> Pyrogram-0.13.0-py3-none-any.whl: pyrogram/api/functions/help/get_app_update.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class GetAppUpdate(Object):
    """Attributes:
        ID: ``0x522d5a7d``

    Parameters:
        source: ``str``

    Returns:
        Either :obj:`help.AppUpdate <pyrogram.api.types.help.AppUpdate>` or :obj:`help.NoAppUpdate <pyrogram.api.types.help.NoAppUpdate>`
    """

    __slots__ = ["source"]

    ID = 0x522d5a7d
    QUALNAME = "functions.help.GetAppUpdate"

    def __init__(self, *, source: str):
        self.source = source  # string

    @staticmethod
    def read(b: BytesIO, *args) -> "GetAppUpdate":
        # No flags
        
        source = String.read(b)
        
        return GetAppUpdate(source=source)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(String(self.source))
        
        return b.getvalue()

==> Pyrogram-0.14.1-py3-none-any.whl: pyrogram/api/functions/help/get_app_update.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2019 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class GetAppUpdate(TLObject):
    """Attributes:
        LAYER: ``100``

    Attributes:
        ID: ``0x522d5a7d``

    Parameters:
        source: ``str``

    Returns:
        Either :obj:`help.AppUpdate <pyrogram.api.types.help.AppUpdate>` or :obj:`help.NoAppUpdate <pyrogram.api.types.help.NoAppUpdate>`
    """

    __slots__ = ["source"]

    ID = 0x522d5a7d
    QUALNAME = "functions.help.GetAppUpdate"

    def __init__(self, *, source: str):
        self.source = source  # string

    @staticmethod
    def read(b: BytesIO, *args) -> "GetAppUpdate":
        # No flags
        
        source = String.read(b)
        
        return GetAppUpdate(source=source)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(String(self.source))
        
        return b.getvalue()
